==> vmaid-2.1.2.tar.gz: vmaid-2.1.2/w32loader/w32btn.h <==
/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __W32BTN_H__
#define __W32BTN_H__


/* ja:ボタンコントロール */
#define BS_PUSHBUTTON      0x00000000
#define BS_DEFPUSHBUTTON   0x00000001
#define BS_CHECKBOX        0x00000002
#define BS_AUTOCHECKBOX    0x00000003
#define BS_RADIOBUTTON     0x00000004
#define BS_3STATE          0x00000005
#define BS_AUTO3STATE      0x00000006
#define BS_GROUPBOX        0x00000007
#define BS_USERBUTTON      0x00000008
#define BS_AUTORADIOBUTTON 0x00000009
#define BS_OWNERDRAW       0x0000000b
#define BS_TYPEMASK        0x0000000f
#define BS_LEFTTEXT        0x00000020
#define BS_RIGHTBUTTON     BS_LEFTTEXT
#define BS_TEXT            0x00000000
#define BS_ICON            0x00000040
#define BS_BITMAP          0x00000080
#define BS_LEFT            0x00000100
#define BS_RIGHT           0x00000200
#define BS_CENTER          0x00000300
#define BS_TOP             0x00000400
#define BS_BOTTOM          0x00000800
#define BS_VCENTER         0x00000c00
#define BS_PUSHLIKE        0x00001000
#define BS_MULTILINE       0x00002000
#define BS_NOTIFY          0x00004000
#define BS_FLAT            0x00008000
#define BM_GETCHECK 0x00f0
#define BM_SETCHECK 0x00f1
#define BM_GETSTATE 0x00f2
#define BM_SETSTATE 0x00f3
#define BM_SETSTYLE 0x00f4
#define BM_CLICK    0x00f5
#define BM_GETIMAGE 0x00f6
#define BM_SETIMAGE 0x00f7
#define BN_CLICKED       0
#define BN_PAINT         1
#define BN_HILITE        2
#define BN_PUSHED        BN_HILITE
#define BN_UNHILITE      3
#define BN_UNPUSHED      BN_UNHILITE
#define BN_DISABLE       4
#define BN_DOUBLECLICKED 5
#define BN_DBLCLK        BN_DOUBLECLICKED
#define BN_SETFOCUS      6
#define BN_KILLFOCUS     7
#define BST_UNCHECKED     0x0000
#define BST_CHECKED       0x0001
#define BST_INDETERMINATE 0x0002
#define BST_PUSHED        0x0004
#define BST_FOCUS         0x0008


#endif /* not __W32BTN_H__ */

==> vmaid-2.2.4.tar.gz: vmaid-2.2.4/w32loader/w32btn.h <==
/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __W32BTN_H__
#define __W32BTN_H__


G_BEGIN_DECLS


/* ja:ボタンコントロール */
#define BS_PUSHBUTTON      0x00000000
#define BS_DEFPUSHBUTTON   0x00000001
#define BS_CHECKBOX        0x00000002
#define BS_AUTOCHECKBOX    0x00000003
#define BS_RADIOBUTTON     0x00000004
#define BS_3STATE          0x00000005
#define BS_AUTO3STATE      0x00000006
#define BS_GROUPBOX        0x00000007
#define BS_USERBUTTON      0x00000008
#define BS_AUTORADIOBUTTON 0x00000009
#define BS_OWNERDRAW       0x0000000b
#define BS_TYPEMASK        0x0000000f
#define BS_LEFTTEXT        0x00000020
#define BS_RIGHTBUTTON     BS_LEFTTEXT
#define BS_TEXT            0x00000000
#define BS_ICON            0x00000040
#define BS_BITMAP          0x00000080
#define BS_LEFT            0x00000100
#define BS_RIGHT           0x00000200
#define BS_CENTER          0x00000300
#define BS_TOP             0x00000400
#define BS_BOTTOM          0x00000800
#define BS_VCENTER         0x00000c00
#define BS_PUSHLIKE        0x00001000
#define BS_MULTILINE       0x00002000
#define BS_NOTIFY          0x00004000
#define BS_FLAT            0x00008000
#define BM_GETCHECK 0x00f0
#define BM_SETCHECK 0x00f1
#define BM_GETSTATE 0x00f2
#define BM_SETSTATE 0x00f3
#define BM_SETSTYLE 0x00f4
#define BM_CLICK    0x00f5
#define BM_GETIMAGE 0x00f6
#define BM_SETIMAGE 0x00f7
#define BN_CLICKED       0
#define BN_PAINT         1
#define BN_HILITE        2
#define BN_PUSHED        BN_HILITE
#define BN_UNHILITE      3
#define BN_UNPUSHED      BN_UNHILITE
#define BN_DISABLE       4
#define BN_DOUBLECLICKED 5
#define BN_DBLCLK        BN_DOUBLECLICKED
#define BN_SETFOCUS      6
#define BN_KILLFOCUS     7
#define BST_UNCHECKED     0x0000
#define BST_CHECKED       0x0001
#define BST_INDETERMINATE 0x0002
#define BST_PUSHED        0x0004
#define BST_FOCUS         0x0008


G_END_DECLS


#endif /* not __W32BTN_H__ */
